==> fm-bridge1-0.1.0.tgz: package/src/index.ts <==
let WebViewJavascriptBridge = (window as any).WebViewJavascriptBridge;
let WVJBCallbacks = (window as any).WVJBCallbacks;

function isAndroid() {
  const u = navigator.userAgent;
  return u.indexOf('Android') > -1 || u.indexOf('Adr') > -1;
}

function isIOS() {
  const u = navigator.userAgent;
  return !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
}

function isFengmang() {
  const u = navigator.userAgent;
  return u.indexOf('fmapp') > -1 || u.indexOf('fmapp') > -1;
}

// iOS装载bridge
function setupWebViewJavascriptBridgeIOS(callback: any) {
  if (WebViewJavascriptBridge) {
    return callback(WebViewJavascriptBridge);
  }
  if (WVJBCallbacks) {
    return WVJBCallbacks.push(callback);
  }
  WVJBCallbacks = [callback];
  let WVJBIframe = document.createElement('iframe');
  WVJBIframe.style.display = 'none';
  WVJBIframe.src = 'https://__bridge_loaded__';
  document.documentElement.appendChild(WVJBIframe);
  setTimeout(function () {
    document.documentElement.removeChild(WVJBIframe);
  }, 0);
}

// android装载bridge
function setupWebViewJavascriptBridgeAndroid(callback: any) {
  console.log('WebViewJavascriptBridge');
  console.log(WebViewJavascriptBridge);
  if (WebViewJavascriptBridge) {
    return new Promise(function (resolve, reject) {
      resolve(WebViewJavascriptBridge);
    }).then((res) => {
      callback(res);
    });
  } else {
    return new Promise(function (resolve, reject) {
      document.addEventListener(
        'WebViewJavascriptBridgeReady',
        function () {
          console.log(
            '监听WebViewJavascriptBridgeReady得到的WebViewJavascriptBridge'
          );
          try {
            WebViewJavascriptBridge = WebViewJavascriptBridge;
          } catch (error) {}
          resolve(WebViewJavascriptBridge);
        },
        false
      );
    }).then((res) => {
      callback(res);
    });
  }
}
// 区分iOS和android的装载方式
const setupWebViewJavascriptBridge = isAndroid()
  ? setupWebViewJavascriptBridgeAndroid
  : setupWebViewJavascriptBridgeIOS;
// 调用方法
function callMethod(method: string, args?: any) {
  // console.log(`h5调用方法名${method}\n参数:${JSON.stringify(args)}`);
  return new Promise(function (resolve, reject) {
    setupWebViewJavascriptBridge(function (bridge: any) {
      bridge.callHandler(
        method,
        JSON.stringify(args),
        function responseCallback(responseData: any) {
          try {
            resolve(JSON.parse(responseData));
          } catch (error) {
            null;
          }
        }
      );
    });
  });
}

// 注册方法
function registerMethod(name: string, func: any) {
  // console.log(`h5注册方法名${name}`);
  setupWebViewJavascriptBridge(function (bridge: any) {
    bridge.registerHandler(name, func);
  });
}

// register Demo 返回值需要callback

const fmBridge = {
  call: callMethod,
  register: registerMethod,
  init: function (params?: any) {
    return callMethod('initFM', params = null);
  },
  getAppInfo: function () {
    if (isIOS()) {
      return new Promise(function (resolve, reject) {
        setupWebViewJavascriptBridge(function (bridge: any) {
          bridge.callHandler(
            'getAppInfo',
            '',
            function responseCallback(responseData: any) {
              try {
                resolve(responseData);
              } catch (error) {
                null;
              }
            }
          );
        });
      });
    }
    return callMethod('getAppInfo');
  },
  getAppBaseInfo: function () {
    return callMethod('getAppBaseInfo');
  },
  updateVersion: function () {
    return callMethod('updateVersion');
  },
  toggleMenuButton: function (params: fengmang.IToggleMenu) {
    // 切换菜单按钮
    return callMethod('toggleMenuButton', params);
  },
  getUserInfo: function () {
    return callMethod('getUserInfo');
  },
  /**
   * 即将废弃
   */
  getShareData: function (shareData = {}) {
    registerMethod('getShareData', function (_: any, callback: any) {
      // console.log('getShareData:', JSON.stringify(shareData));
      callback(JSON.stringify(shareData));
    });
  },
  updateUserInfo: function (func: any) {
    registerMethod('updateUserInfo', function (data: any, callback: any) {
      console.log('更新用户信息', data);
      func(JSON.parse(data));
    });
  },
  openUI: function (args: fengmang.IOpenUI) {
    return callMethod('openUI', args);
  },
  showMenuItems: function (params: fengmang.IShowMenuItems) {
    registerMethod('showMenuItems', function (_: any, callback: any) {
      callback(JSON.stringify(params));
    });
  },
  updateNetwork: function (func: any) {
    console.log('updateNetwork');
    registerMethod('updateNetwork', function (data: any, callback: any) {
      console.log('更新用户网络', data);
      func(JSON.parse(data));
    });
  },
  copy: function (
    /**
     *链接地址
     */
    url: string
  ) {
    registerMethod('copy', function (data: any, callback: any) {
      console.log('copy', url);
      try {
        callback(
          JSON.stringify({ url: url || 'https://ls.mangguonews.com/mgndload' })
        );
      } catch (error) {
        console.log(error);
      }
    });
  },
  share: function (params: fengmang.IShare) {
    registerMethod('share', function (data: any, callback: any) {
      console.log('share', params);
      try {
        callback(JSON.stringify(params));
      } catch (error) {
        console.log(error);
      }
    });
  },
  like: function (params: fengmang.ILike) {
    console.log('like', params);
    registerMethod('like', function (data: any, callback: any) {
      console.log('like', params);
      try {
        callback(JSON.stringify(params));
      } catch (error) {
        console.log(error);
      }
    });
  },
  collect: function (params: fengmang.ICollect) {
    registerMethod('collect', function (data: any, callback: any) {
      console.log('collect', params);
      try {
        callback(JSON.stringify(params));
      } catch (error) {
        console.log(error);
      }
    });
  },
  popToUI: function (params: fengmang.IPopToUI) {
    return callMethod('popToUI', params);
  },
  openURL: function (params: fengmang.IOpenURL) {
    return callMethod('openURL', params);
  },
  cancelAccount: function (params: fengmang.ICancelAccount) {
    return callMethod('cancelAccount', params);
  },
  accountConflict: function (params: fengmang.IAccountConflict) {
    return callMethod('accountConflict', params);
  },
  toggleBackButton: function (params: fengmang.IToggleBackButton) {
    return callMethod('toggleBackButton', params);
  },
  popGesture: function (params: fengmang.IPopGesture) {
    return callMethod('popGesture', params);
  },
  isFengmang: isFengmang(),
};

(window as any).fmBridge = fmBridge;

export default fmBridge;

==> fm-bridge1-0.1.1.tgz: package/src/index.ts <==
let WebViewJavascriptBridge = (window as any).WebViewJavascriptBridge;
let WVJBCallbacks = (window as any).WVJBCallbacks;

function isAndroid() {
  const u = navigator.userAgent;
  return u.indexOf('Android') > -1 || u.indexOf('Adr') > -1;
}

function isIOS() {
  const u = navigator.userAgent;
  return !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
}

// iOS装载bridge
function setupWebViewJavascriptBridgeIOS(callback: any) {
  if (WebViewJavascriptBridge) {
    return callback(WebViewJavascriptBridge);
  }
  if (WVJBCallbacks) {
    return WVJBCallbacks.push(callback);
  }
  WVJBCallbacks = [callback];
  let WVJBIframe = document.createElement('iframe');
  WVJBIframe.style.display = 'none';
  WVJBIframe.src = 'https://__bridge_loaded__';
  document.documentElement.appendChild(WVJBIframe);
  setTimeout(function () {
    document.documentElement.removeChild(WVJBIframe);
  }, 0);
}

// android装载bridge
function setupWebViewJavascriptBridgeAndroid(callback: any) {
  console.log('WebViewJavascriptBridge');
  console.log(WebViewJavascriptBridge);
  if (WebViewJavascriptBridge) {
    return new Promise(function (resolve, reject) {
      resolve(WebViewJavascriptBridge);
    }).then((res) => {
      callback(res);
    });
  } else {
    return new Promise(function (resolve, reject) {
      document.addEventListener(
        'WebViewJavascriptBridgeReady',
        function () {
          console.log(
            '监听WebViewJavascriptBridgeReady得到的WebViewJavascriptBridge'
          );
          try {
            WebViewJavascriptBridge = WebViewJavascriptBridge;
          } catch (error) {}
          resolve(WebViewJavascriptBridge);
        },
        false
      );
    }).then((res) => {
      callback(res);
    });
  }
}
// 区分iOS和android的装载方式
const setupWebViewJavascriptBridge = isAndroid()
  ? setupWebViewJavascriptBridgeAndroid
  : setupWebViewJavascriptBridgeIOS;
// 调用方法
function callMethod(method: string, args?: any) {
  // console.log(`h5调用方法名${method}\n参数:${JSON.stringify(args)}`);
  return new Promise(function (resolve, reject) {
    setupWebViewJavascriptBridge(function (bridge: any) {
      bridge.callHandler(
        method,
        JSON.stringify(args),
        function responseCallback(responseData: any) {
          try {
            resolve(JSON.parse(responseData));
          } catch (error) {
            null;
          }
        }
      );
    });
  });
}

// 注册方法
function registerMethod(name: string, func: any) {
  // console.log(`h5注册方法名${name}`);
  setupWebViewJavascriptBridge(function (bridge: any) {
    bridge.registerHandler(name, func);
  });
}

// register Demo 返回值需要callback

const fmBridge = {
  call: callMethod,
  register: registerMethod,
  init: function (params?: any) {
    return callMethod('initFM', params = null);
  },
  getAppInfo: function () {
    if (isIOS()) {
      return new Promise(function (resolve, reject) {
        setupWebViewJavascriptBridge(function (bridge: any) {
          bridge.callHandler(
            'getAppInfo',
            '',
            function responseCallback(responseData: any) {
              try {
                resolve(responseData);
              } catch (error) {
                null;
              }
            }
          );
        });
      });
    }
    return callMethod('getAppInfo');
  },
  getAppBaseInfo: function () {
    return callMethod('getAppBaseInfo');
  },
  updateVersion: function () {
    return callMethod('updateVersion');
  },
  toggleMenuButton: function (params: fengmang.IToggleMenu) {
    // 切换菜单按钮
    return callMethod('toggleMenuButton', params);
  },
  getUserInfo: function () {
    return callMethod('getUserInfo');
  },
  /**
   * 即将废弃
   */
  getShareData: function (shareData = {}) {
    registerMethod('getShareData', function (_: any, callback: any) {
      // console.log('getShareData:', JSON.stringify(shareData));
      callback(JSON.stringify(shareData));
    });
  },
  updateUserInfo: function (func: any) {
    registerMethod('updateUserInfo', function (data: any, callback: any) {
      console.log('更新用户信息', data);
      func(JSON.parse(data));
    });
  },
  openUI: function (args: fengmang.IOpenUI) {
    return callMethod('openUI', args);
  },
  showMenuItems: function (params: fengmang.IShowMenuItems) {
    registerMethod('showMenuItems', function (_: any, callback: any) {
      callback(JSON.stringify(params));
    });
  },
  updateNetwork: function (func: any) {
    console.log('updateNetwork');
    registerMethod('updateNetwork', function (data: any, callback: any) {
      console.log('更新用户网络', data);
      func(JSON.parse(data));
    });
  },
  copy: function (
    /**
     *链接地址
     */
    url: string
  ) {
    registerMethod('copy', function (data: any, callback: any) {
      console.log('copy', url);
      try {
        callback(
          JSON.stringify({ url: url || 'https://ls.mangguonews.com/mgndload' })
        );
      } catch (error) {
        console.log(error);
      }
    });
  },
  share: function (params: fengmang.IShare) {
    registerMethod('share', function (data: any, callback: any) {
      console.log('share', params);
      try {
        callback(JSON.stringify(params));
      } catch (error) {
        console.log(error);
      }
    });
  },
  like: function (params: fengmang.ILike) {
    console.log('like', params);
    registerMethod('like', function (data: any, callback: any) {
      console.log('like', params);
      try {
        callback(JSON.stringify(params));
      } catch (error) {
        console.log(error);
      }
    });
  },
  collect: function (params: fengmang.ICollect) {
    registerMethod('collect', function (data: any, callback: any) {
      console.log('collect', params);
      try {
        callback(JSON.stringify(params));
      } catch (error) {
        console.log(error);
      }
    });
  },
  popToUI: function (params: fengmang.IPopToUI) {
    return callMethod('popToUI', params);
  },
  openURL: function (params: fengmang.IOpenURL) {
    return callMethod('openURL', params);
  },
  cancelAccount: function (params: fengmang.ICancelAccount) {
    return callMethod('cancelAccount', params);
  },
  accountConflict: function (params: fengmang.IAccountConflict) {
    return callMethod('accountConflict', params);
  },
  toggleBackButton: function (params: fengmang.IToggleBackButton) {
    return callMethod('toggleBackButton', params);
  },
  popGesture: function (params: fengmang.IPopGesture) {
    return callMethod('popGesture', params);
  },
  isFengmang: function isFengmang() {
    const u = navigator.userAgent;
    return u.indexOf('fmapp') > -1 || u.indexOf('fmapp') > -1;
  },
};

(window as any).fmBridge = fmBridge;

export default fmBridge;
